import React, { Fragment } from 'react';
import './App.scss';
import { BryntumGantt } from '@bryntum/gantt-react';
import CustomEditor from './CustomEditor';

const App = () => {
    return (
        <Fragment>
            <BryntumGantt
                startDate={"2023-01-01"}
                endDate={"2023-01-30"}
                columns={[
                    {
                        type: 'name',
                        field: 'name',
                        width: 250,

                        // Lost values in "Custom editor" column is related to React 18 + lack of renderer for the
                        // name column. Switching back to React 16 or enabling the renderer below fixes the problem.
                        // REMEBER: The app must be started with different approaches, depending on which version of
                        // React is being used. See index.js for details.
                        renderer: ({record}) => {
                            return record.isLeaf ? <span>{record.name}</span> : <b>{record.name}</b>
                        }
                    },
                    {
                        field: "Prop_e01d93cc-fc6b-47d6-b9cf-8fb51f168354",
                        text: "Custom editor",
                        width: 250,
                        renderer: (args) => {
                            return args.value;
                        },
                        editor: ref => <CustomEditor ref={ref} />
                    }
                ]}
                tasks={[
                    {
                        id: "item1",
                        name: "Test 1",
                        "Prop_e01d93cc-fc6b-47d6-b9cf-8fb51f168354": null,
                        startDate: "2023-01-05",
                        endDate: "2023-01-10"
                    },
                    {
                        id: "item2",
                        name: "Test 2",
                        "Prop_e01d93cc-fc6b-47d6-b9cf-8fb51f168354": "Okay okay",
                        startDate: "2023-01-10",
                        endDate: "2023-01-14"
                    },
                    {
                        id: "item3",
                        name: "Test 3",
                        "Prop_e01d93cc-fc6b-47d6-b9cf-8fb51f168354": null,
                        startDate: "2023-01-18",
                        endDate: "2023-01-20"
                    },
                    {
                        id: "item4",
                        name: "Test 4",
                        "Prop_e01d93cc-fc6b-47d6-b9cf-8fb51f168354": null,
                        startDate: "2023-01-22",
                        endDate: "2023-01-25"
                    },
                    {
                        id: "item5",
                        name: "Test 5",
                        "Prop_e01d93cc-fc6b-47d6-b9cf-8fb51f168354": null,
                        startDate: "2023-01-25",
                        endDate: "2023-01-30"
                    },
                    {
                        id: "item6",
                        name: "Test 6",
                        "Prop_e01d93cc-fc6b-47d6-b9cf-8fb51f168354": null,
                        startDate: "2023-01-08",
                        endDate: "2023-01-20"
                    }
                ]}
            />
        </Fragment>
    );
};

export default App;
